@@ -27,8 +27,6 @@ describe 'keystone' do
       'admin_bind_host'                    => '0.0.0.0',
       'public_port'                        => '5000',
       'admin_port'                         => '35357',
-      'debug'                              => false,
-      'use_stderr'                         => true,
       'catalog_type'                       => 'sql',
       'catalog_driver'                     => false,
       'token_provider'                     => 'fernet',
@@ -37,8 +35,6 @@ describe 'keystone' do
       'password_hash_rounds'               => '<SERVICE DEFAULT>',
       'revoke_driver'                      => 'sql',
       'revoke_by_id'                       => true,
-      'cache_dir'                          => '/var/cache/keystone',
-      'memcache_servers'                   => '<SERVICE DEFAULT>',
       'cache_backend'                      => '<SERVICE DEFAULT>',
       'cache_backend_argument'             => '<SERVICE DEFAULT>',
       'cache_enabled'                      => '<SERVICE DEFAULT>',
@@ -53,12 +49,6 @@ describe 'keystone' do
       'manage_service'                     => true,
       'database_connection'                => 'sqlite:////var/lib/keystone/keystone.db',
       'database_idle_timeout'              => '200',
-      'signing_certfile'                   => '<SERVICE DEFAULT>',
-      'signing_keyfile'                    => '<SERVICE DEFAULT>',
-      'signing_ca_certs'                   => '<SERVICE DEFAULT>',
-      'signing_ca_key'                     => '<SERVICE DEFAULT>',
-      'signing_cert_subject'               => '<SERVICE DEFAULT>',
-      'signing_key_size'                   => '<SERVICE DEFAULT>',
       'default_transport_url'              => '<SERVICE DEFAULT>',
       'notification_transport_url'         => '<SERVICE DEFAULT>',
       'rabbit_heartbeat_timeout_threshold' => '<SERVICE DEFAULT>',
@@ -68,7 +58,6 @@ describe 'keystone' do
       'public_workers'                     => 20,
       'member_role_id'                     => '<SERVICE DEFAULT>',
       'member_role_name'                   => '<SERVICE DEFAULT>',
-      'paste_config'                       => '<SERVICE DEFAULT>',
       'sync_db'                            => true,
       'purge_config'                       => false,
       'keystone_user'                      => 'keystone',
@@ -84,8 +73,6 @@ describe 'keystone' do
       'admin_port'                         => '35358',
       'admin_token'                        => 'service_token_override',
       'admin_password'                     => 'admin_openstack_password',
-      'debug'                              => true,
-      'use_stderr'                         => false,
       'catalog_type'                       => 'template',
       'token_provider'                     => 'uuid',
       'token_driver'                       => 'kvs',
@@ -105,13 +92,6 @@ describe 'keystone' do
       'manage_service'                     => true,
       'database_connection'                => 'mysql://a:b@c/d',
       'database_idle_timeout'              => '300',
-      'enable_pki_setup'                   => true,
-      'signing_certfile'                   => '/etc/keystone/ssl/certs/signing_cert.pem',
-      'signing_keyfile'                    => '/etc/keystone/ssl/private/signing_key.pem',
-      'signing_ca_certs'                   => '/etc/keystone/ssl/certs/ca.pem',
-      'signing_ca_key'                     => '/etc/keystone/ssl/private/cakey.pem',
-      'signing_cert_subject'               => '/C=US/ST=Unset/L=Unset/O=Unset/CN=www.example.com',
-      'signing_key_size'                   => 2048,
       'default_transport_url'              => 'rabbit://user:pass@host:1234/virt',
       'notification_transport_url'         => 'rabbit://user:pass@host:1234/virt',
       'rabbit_heartbeat_timeout_threshold' => '60',
@@ -121,7 +101,6 @@ describe 'keystone' do
       'default_domain'                     => 'other_domain',
       'member_role_id'                     => '123456789',
       'member_role_name'                   => 'othermember',
-      'paste_config'                       => '/usr/share/keystone/keystone-paste.ini',
       'using_domain_config'                => false,
       'keystone_user'                      => 'test_user',
       'keystone_group'                     => 'test_group',
@@ -182,8 +161,6 @@ describe 'keystone' do
        'admin_port',
        'member_role_id',
        'member_role_name',
-       'debug',
-       'use_stderr'
       ].each do |config|
         is_expected.to contain_keystone_config("DEFAULT/#{config}").with_value(param_hash[config])
       end
@@ -222,10 +199,6 @@ describe 'keystone' do
       is_expected.to contain_keystone_config('token/revoke_by_id').with_value(param_hash['revoke_by_id'])
     end
 
-    it 'should contain default paste_config' do
-      is_expected.to contain_keystone_config('paste_deploy/config_file').with_value(param_hash['paste_config'])
-    end
-
     it 'should ensure proper setting of admin_endpoint and public_endpoint' do
       if param_hash['admin_endpoint']
         is_expected.to contain_keystone_config('DEFAULT/admin_endpoint').with_value(param_hash['admin_endpoint'])
@@ -379,135 +352,6 @@ describe 'keystone' do
           'token_provider' => 'keystone.token.providers.uuid.Provider'
         }
       end
-
-      describe 'pki_setup is disabled by default' do
-        it { is_expected.to_not contain_exec('keystone-manage pki_setup') }
-        it { is_expected.to_not contain_file('/var/cache/keystone').with_ensure('directory') }
-      end
-    end
-
-    describe 'when configuring as PKI' do
-      let :params do
-        {
-          'enable_pki_setup'     => true,
-          'admin_token'          => 'service_token',
-          'token_provider'       => 'pki',
-          'signing_certfile'     => '/etc/keystone/ssl/certs/signing_cert.pem',
-          'signing_keyfile'      => '/etc/keystone/ssl/private/signing_key.pem',
-          'signing_ca_certs'     => '/etc/keystone/ssl/certs/ca.pem',
-          'signing_ca_key'       => '/etc/keystone/ssl/private/cakey.pem',
-          'signing_cert_subject' => '/C=US/ST=Unset/L=Unset/O=Unset/CN=www.example.com',
-          'signing_key_size'     => 2048,
-          'keystone_user'        => 'keystone',
-          'keystone_group'       => 'keystone',
-        }
-      end
-
-      it { is_expected.to contain_file('/var/cache/keystone').with_ensure('directory') }
-
-      describe 'when overriding the cache dir' do
-        before do
-          params.merge!(:cache_dir => '/var/lib/cache/keystone')
-        end
-        it { is_expected.to contain_file('/var/lib/cache/keystone') }
-      end
-
-      it { is_expected.to contain_exec('keystone-manage pki_setup').with(
-        :command => "keystone-manage pki_setup --keystone-user #{params['keystone_user']} --keystone-group #{params['keystone_group']}",
-        :creates => '/etc/keystone/ssl/private/signing_key.pem'
-      ) }
-      it { is_expected.to contain_file('/var/cache/keystone').with_ensure('directory') }
-
-      describe 'when overriding the cache dir' do
-        before do
-          params.merge!(:cache_dir => '/var/lib/cache/keystone')
-        end
-        it { is_expected.to contain_file('/var/lib/cache/keystone') }
-      end
-    end
-
-    describe 'when configuring PKI signing cert paths with UUID and with pki_setup disabled' do
-      let :params do
-        {
-          'admin_token'          => 'service_token',
-          'token_provider'       => 'uuid',
-          'enable_pki_setup'     => false,
-          'signing_certfile'     => 'signing_certfile',
-          'signing_keyfile'      => 'signing_keyfile',
-          'signing_ca_certs'     => 'signing_ca_certs',
-          'signing_ca_key'       => 'signing_ca_key',
-          'signing_cert_subject' => 'signing_cert_subject',
-          'signing_key_size'     => 2048
-        }
-      end
-
-      it { is_expected.to_not contain_exec('keystone-manage pki_setup') }
-
-      it 'should contain correct PKI certfile config' do
-        is_expected.to contain_keystone_config('signing/certfile').with_value('signing_certfile')
-      end
-
-      it 'should contain correct PKI keyfile config' do
-        is_expected.to contain_keystone_config('signing/keyfile').with_value('signing_keyfile')
-      end
-
-      it 'should contain correct PKI ca_certs config' do
-        is_expected.to contain_keystone_config('signing/ca_certs').with_value('signing_ca_certs')
-      end
-
-      it 'should contain correct PKI ca_key config' do
-        is_expected.to contain_keystone_config('signing/ca_key').with_value('signing_ca_key')
-      end
-
-      it 'should contain correct PKI cert_subject config' do
-        is_expected.to contain_keystone_config('signing/cert_subject').with_value('signing_cert_subject')
-      end
-
-      it 'should contain correct PKI key_size config' do
-        is_expected.to contain_keystone_config('signing/key_size').with_value('2048')
-      end
-    end
-
-    describe 'when configuring PKI signing cert paths with pki_setup disabled' do
-      let :params do
-        {
-          'admin_token'          => 'service_token',
-          'token_provider'       => 'pki',
-          'enable_pki_setup'     => false,
-          'signing_certfile'     => 'signing_certfile',
-          'signing_keyfile'      => 'signing_keyfile',
-          'signing_ca_certs'     => 'signing_ca_certs',
-          'signing_ca_key'       => 'signing_ca_key',
-          'signing_cert_subject' => 'signing_cert_subject',
-          'signing_key_size'     => 2048
-        }
-      end
-
-      it { is_expected.to_not contain_exec('keystone-manage pki_setup') }
-
-      it 'should contain correct PKI certfile config' do
-        is_expected.to contain_keystone_config('signing/certfile').with_value('signing_certfile')
-      end
-
-      it 'should contain correct PKI keyfile config' do
-        is_expected.to contain_keystone_config('signing/keyfile').with_value('signing_keyfile')
-      end
-
-      it 'should contain correct PKI ca_certs config' do
-        is_expected.to contain_keystone_config('signing/ca_certs').with_value('signing_ca_certs')
-      end
-
-      it 'should contain correct PKI ca_key config' do
-        is_expected.to contain_keystone_config('signing/ca_key').with_value('signing_ca_key')
-      end
-
-      it 'should contain correct PKI cert_subject config' do
-        is_expected.to contain_keystone_config('signing/cert_subject').with_value('signing_cert_subject')
-      end
-
-      it 'should contain correct PKI key_size config' do
-        is_expected.to contain_keystone_config('signing/key_size').with_value('2048')
-      end
     end
 
     describe 'with invalid catalog_type' do
@@ -576,10 +420,10 @@ describe 'keystone' do
     let :params do
       {
         'admin_token'                  => 'service_token',
-        'memcache_servers'             => [ 'SERVER1:11211', 'SERVER2:11211' ],
         'token_driver'                 => 'memcache',
         'cache_backend'                => 'dogpile.cache.memcached',
         'cache_backend_argument'       => ['url:SERVER1:12211'],
+        'cache_memcache_servers'       => 'SERVER1:11211,SERVER2:11211',
         'memcache_dead_retry'          => '60',
         'memcache_socket_timeout'      => '2',
         'memcache_pool_maxsize'        => '1000',
@@ -587,8 +431,7 @@ describe 'keystone' do
       }
     end
 
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('SERVER1:11211,SERVER2:11211') }
-    it { is_expected.to contain_keystone_config('cache/enabled').with_value(true) }
+    it { is_expected.to contain_keystone_config('cache/enabled').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
     it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER1:12211') }
@@ -618,11 +461,10 @@ describe 'keystone' do
     let :params do
       {
         'admin_token'                          => 'service_token',
-        'memcache_servers'                     => [ 'SERVER1:11211', 'SERVER2:11211' ],
         'token_driver'                         => 'noop',
         'cache_backend'                        => 'dogpile.cache.memcached',
         'cache_backend_argument'               => ['url:SERVER3:12211'],
-        'cache_memcache_servers'               => [ 'SERVER3:11211', 'SERVER4:11211' ],
+        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211' ],
         'memcache_dead_retry'                  => '60',
         'memcache_socket_timeout'              => '2',
         'memcache_pool_maxsize'                => '1000',
@@ -632,7 +474,41 @@ describe 'keystone' do
       }
     end
 
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_keystone_config('cache/enabled').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
+    it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER3:12211') }
+    it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
+    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
+    it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
+    it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
+    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
+    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
+    it { is_expected.to contain_oslo__cache('keystone_config').with_manage_backend_package(false) }
+    it { is_expected.not_to contain_package('python-memcache') }
+  end
+
+  describe 'configure cache enabled if set' do
+    let :params do
+      {
+        'admin_token'                          => 'service_token',
+        'token_driver'                         => 'memcache',
+        'cache_backend'                        => 'dogpile.cache.memcached',
+        'cache_backend_argument'               => ['url:SERVER3:12211'],
+        'cache_enabled'                        => true,
+        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211' ],
+        'memcache_dead_retry'                  => '60',
+        'memcache_socket_timeout'              => '2',
+        'memcache_pool_maxsize'                => '1000',
+        'memcache_pool_unused_timeout'         => '60',
+        'memcache_pool_connection_get_timeout' => '30',
+      }
+    end
+
     it { is_expected.to contain_keystone_config('cache/enabled').with_value(true) }
     it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
@@ -646,44 +522,7 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
     it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER3:11211,SERVER4:11211') }
-    it { is_expected.to contain_oslo__cache('keystone_config').with_manage_backend_package(false) }
-    it { is_expected.not_to contain_package('python-memcache') }
-  end
-
-  describe 'configure cache enabled if set' do
-    let :params do
-      {
-        'admin_token'                          => 'service_token',
-        'memcache_servers'                     => [ 'SERVER1:11211', 'SERVER2:11211' ],
-        'token_driver'                         => 'memcache',
-        'cache_backend'                        => 'dogpile.cache.memcached',
-        'cache_backend_argument'               => ['url:SERVER3:12211'],
-        'cache_enabled'                        => false,
-        'cache_memcache_servers'               => [ 'SERVER3:11211', 'SERVER4:11211' ],
-        'memcache_dead_retry'                  => '60',
-        'memcache_socket_timeout'              => '2',
-        'memcache_pool_maxsize'                => '1000',
-        'memcache_pool_unused_timeout'         => '60',
-        'memcache_pool_connection_get_timeout' => '30',
-      }
-    end
-
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('SERVER1:11211,SERVER2:11211') }
-    it { is_expected.to contain_keystone_config('cache/enabled').with_value(false) }
-    it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
-    it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER3:12211') }
-    it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2') }
-    it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER3:11211,SERVER4:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
     it { is_expected.to contain_package('python-memcache').with(
       :name   => 'python-memcache',
       :ensure => 'present'
@@ -693,13 +532,11 @@ describe 'keystone' do
   describe 'configure memcache servers with a string' do
     let :params do
       default_params.merge({
-        'memcache_servers'       => 'SERVER1:11211,SERVER2:11211',
-        'cache_memcache_servers' => 'SERVER3:11211,SERVER4:11211'
+        'cache_memcache_servers' => 'SERVER1:11211,SERVER2:11211'
       })
     end
 
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('SERVER1:11211,SERVER2:11211') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER3:11211,SERVER4:11211') }
+    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211') }
   end
 
   describe 'do not configure memcache servers when not set' do
@@ -712,7 +549,6 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config("cache/backend").with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config("cache/backend_argument").with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config("cache/debug_cache_backend").with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config("memcache/servers").with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('<SERVICE DEFAULT>') }
     it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('<SERVICE DEFAULT>') }
